==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/spellchecker/translations/spellchecker_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>SpellChecker</source>
        <translation>Program na ověření pravopisu</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Volby pro označení špatně napsaných slov</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podtržení</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Volby pro ověření správného psaní</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Nevšímat si velikosti písmen</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Volby pro návrhy pravopisu</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Ukázat návrhy</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Nejvyšší počet navržených slov</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Nepodařilo se najít slovník pro %1 jazyk.</translation>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Přesunout do &apos;Ověřeno&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Dostupné jazyky</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Přesunout do &apos;Dostupné jazyky&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Ověřeno</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/spellchecker/translations/spellchecker_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Volby pro označení špatně napsaných slov</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podtržení</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Volby pro ověření správného psaní</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Nevšímat si velikosti písmen</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Volby pro návrhy pravopisu</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Ukázat návrhy</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Nejvyšší počet navržených slov</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Pravopis</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Nepodařilo se najít slovník pro %1 jazyk.</translation>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Přesunout do &apos;Ověřeno&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Dostupné jazyky</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Přesunout do &apos;Dostupné jazyky&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Ověřeno</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
</context>
</TS>
